@@ -190,13 +190,14 @@ arv_gv_discover_socket_list_send_discover_packet (ArvGvDiscoverSocketList *socke
 /* ArvGvInterfaceDeviceInfos implementation */
 
 typedef struct {
-	char *name;
-	char *full_name;
-	char *user_name;
-	char *manufacturer;
+	char *id;
+	char *user_id;
+	char *vendor_serial;
+	char *vendor_alias_serial;
+	char *vendor;
 	char *model;
-	char *serial_number;
-	char *mac_string;
+	char *serial;
+	char *mac;
 
 	GInetAddress *interface_address;
 
@@ -220,29 +221,33 @@ arv_gv_interface_device_infos_new (GInetAddress *interface_address,
 
 	memcpy (infos->discovery_data, discovery_data, ARV_GVBS_DISCOVERY_DATA_SIZE);
 
-	infos->manufacturer = g_strndup ((char *) &infos->discovery_data[ARV_GVBS_MANUFACTURER_NAME_OFFSET],
-					 ARV_GVBS_MANUFACTURER_NAME_SIZE);
+	infos->vendor = g_strndup ((char *) &infos->discovery_data[ARV_GVBS_MANUFACTURER_NAME_OFFSET],
+				   ARV_GVBS_MANUFACTURER_NAME_SIZE);
 	infos->model = g_strndup ((char *) &infos->discovery_data[ARV_GVBS_MODEL_NAME_OFFSET],
 				  ARV_GVBS_MODEL_NAME_SIZE);
-	infos->serial_number = g_strndup ((char *) &infos->discovery_data[ARV_GVBS_SERIAL_NUMBER_OFFSET],
-					  ARV_GVBS_SERIAL_NUMBER_SIZE);
-	infos->user_name = g_strndup ((char *) &infos->discovery_data[ARV_GVBS_USER_DEFINED_NAME_OFFSET],
-				      ARV_GVBS_USER_DEFINED_NAME_SIZE);
+	infos->serial = g_strndup ((char *) &infos->discovery_data[ARV_GVBS_SERIAL_NUMBER_OFFSET],
+				   ARV_GVBS_SERIAL_NUMBER_SIZE);
+	infos->user_id = g_strndup ((char *) &infos->discovery_data[ARV_GVBS_USER_DEFINED_NAME_OFFSET],
+				    ARV_GVBS_USER_DEFINED_NAME_SIZE);
 
-	infos->name = g_strdup_printf ("%s-%s", arv_vendor_alias_lookup (infos->manufacturer), infos->serial_number);
-	arv_str_strip (infos->name, ARV_DEVICE_NAME_ILLEGAL_CHARACTERS, ARV_DEVICE_NAME_REPLACEMENT_CHARACTER);
-	infos->full_name = g_strdup_printf ("%s-%s", infos->manufacturer, infos->serial_number);
-	arv_str_strip (infos->full_name, ARV_DEVICE_NAME_ILLEGAL_CHARACTERS, ARV_DEVICE_NAME_REPLACEMENT_CHARACTER);
+	infos->id = g_strdup_printf ("%s-%s-%s", infos->vendor, infos->model, infos->serial);
+	arv_str_strip (infos->id, ARV_DEVICE_NAME_ILLEGAL_CHARACTERS, ARV_DEVICE_NAME_REPLACEMENT_CHARACTER);
+
+	infos->vendor_alias_serial = g_strdup_printf ("%s-%s", arv_vendor_alias_lookup (infos->vendor), infos->serial);
+	arv_str_strip (infos->vendor_alias_serial, ARV_DEVICE_NAME_ILLEGAL_CHARACTERS, ARV_DEVICE_NAME_REPLACEMENT_CHARACTER);
+
+	infos->vendor_serial = g_strdup_printf ("%s-%s", infos->vendor, infos->serial);
+	arv_str_strip (infos->vendor_serial, ARV_DEVICE_NAME_ILLEGAL_CHARACTERS, ARV_DEVICE_NAME_REPLACEMENT_CHARACTER);
 
 	infos->interface_address = interface_address;
 
-	infos->mac_string = g_strdup_printf ("%02x:%02x:%02x:%02x:%02x:%02x",
-					     infos->discovery_data[ARV_GVBS_DEVICE_MAC_ADDRESS_HIGH_OFFSET + 2],
-					     infos->discovery_data[ARV_GVBS_DEVICE_MAC_ADDRESS_HIGH_OFFSET + 3],
-					     infos->discovery_data[ARV_GVBS_DEVICE_MAC_ADDRESS_HIGH_OFFSET + 4],
-					     infos->discovery_data[ARV_GVBS_DEVICE_MAC_ADDRESS_HIGH_OFFSET + 5],
-					     infos->discovery_data[ARV_GVBS_DEVICE_MAC_ADDRESS_HIGH_OFFSET + 6],
-					     infos->discovery_data[ARV_GVBS_DEVICE_MAC_ADDRESS_HIGH_OFFSET + 7]);
+	infos->mac = g_strdup_printf ("%02x:%02x:%02x:%02x:%02x:%02x",
+				      infos->discovery_data[ARV_GVBS_DEVICE_MAC_ADDRESS_HIGH_OFFSET + 2],
+				      infos->discovery_data[ARV_GVBS_DEVICE_MAC_ADDRESS_HIGH_OFFSET + 3],
+				      infos->discovery_data[ARV_GVBS_DEVICE_MAC_ADDRESS_HIGH_OFFSET + 4],
+				      infos->discovery_data[ARV_GVBS_DEVICE_MAC_ADDRESS_HIGH_OFFSET + 5],
+				      infos->discovery_data[ARV_GVBS_DEVICE_MAC_ADDRESS_HIGH_OFFSET + 6],
+				      infos->discovery_data[ARV_GVBS_DEVICE_MAC_ADDRESS_HIGH_OFFSET + 7]);
 	infos->ref_count = 1;
 
 	return infos;
@@ -267,13 +272,14 @@ arv_gv_interface_device_infos_unref (ArvGvInterfaceDeviceInfos *infos)
 
 	if (g_atomic_int_dec_and_test (&infos->ref_count)) {
 		g_object_unref (infos->interface_address);
-		g_free (infos->name);
-		g_free (infos->user_name);
-		g_free (infos->full_name);
-		g_free (infos->manufacturer);
-		g_free (infos->serial_number);
+		g_free (infos->id);
+		g_free (infos->user_id);
+		g_free (infos->vendor_serial);
+		g_free (infos->vendor_alias_serial);
+		g_free (infos->vendor);
 		g_free (infos->model);
-		g_free (infos->mac_string);
+		g_free (infos->serial);
+		g_free (infos->mac);
 		g_free (infos);
 	}
 }
@@ -343,33 +349,36 @@ _discover (GHashTable *devices, const char *device_id)
 						address_string = g_inet_address_to_string (interface_address);
 
 						arv_debug_interface ("[GvInterface::discovery] Device '%s' found "
-								     "(interface %s) user_name '%s' - MAC_name '%s'",
-								     device_infos->name,
+								     "(interface %s) user_id '%s' - MAC '%s'",
+								     device_infos->id,
 								     address_string,
-								     device_infos->user_name,
-								     device_infos->full_name,
-								     device_infos->mac_string);
+								     device_infos->user_id,
+								     device_infos->mac);
 
 						g_free (address_string);
 
 						if (devices != NULL) {
-							if (device_infos->name != NULL && device_infos->name[0] != '\0')
-								g_hash_table_replace (devices, device_infos->name,
+							if (device_infos->id != NULL && device_infos->id[0] != '\0')
+								g_hash_table_replace (devices, device_infos->id,
 										      arv_gv_interface_device_infos_ref (device_infos));
-							if (device_infos->full_name != NULL && device_infos->full_name[0] != '\0')
-								g_hash_table_replace (devices, device_infos->full_name,
+							if (device_infos->user_id != NULL && device_infos->user_id[0] != '\0')
+								g_hash_table_replace (devices, device_infos->user_id,
 										      arv_gv_interface_device_infos_ref (device_infos));
-							if (device_infos->user_name != NULL && device_infos->user_name[0] != '\0')
-								g_hash_table_replace (devices, device_infos->user_name,
+							if (device_infos->vendor_serial != NULL && device_infos->vendor_serial[0] != '\0')
+								g_hash_table_replace (devices, device_infos->vendor_serial,
 										      arv_gv_interface_device_infos_ref (device_infos));
-							g_hash_table_replace (devices, device_infos->mac_string,
+							if (device_infos->vendor_alias_serial != NULL && device_infos->vendor_alias_serial[0] != '\0')
+								g_hash_table_replace (devices, device_infos->vendor_alias_serial,
+										      arv_gv_interface_device_infos_ref (device_infos));
+							g_hash_table_replace (devices, device_infos->mac,
 									      arv_gv_interface_device_infos_ref (device_infos));
 						} else {
 							if (device_id == NULL ||
-							    g_strcmp0 (device_infos->name, device_id) == 0 ||
-							    g_strcmp0 (device_infos->full_name, device_id) == 0 ||
-							    g_strcmp0 (device_infos->user_name, device_id) == 0 ||
-							    g_strcmp0 (device_infos->mac_string, device_id) == 0) {
+							    g_strcmp0 (device_infos->id, device_id) == 0 ||
+							    g_strcmp0 (device_infos->user_id, device_id) == 0 ||
+							    g_strcmp0 (device_infos->vendor_serial, device_id) == 0 ||
+							    g_strcmp0 (device_infos->vendor_alias_serial, device_id) == 0 ||
+							    g_strcmp0 (device_infos->mac, device_id) == 0) {
 								arv_gv_discover_socket_list_free (socket_list);
 
 								return device_infos;
@@ -419,22 +428,23 @@ arv_gv_interface_update_device_list (ArvInterface *interface, GArray *device_ids
 	while (g_hash_table_iter_next (&iter, &key, &value)) {
 		ArvGvInterfaceDeviceInfos *infos = value;
 
-		if (g_strcmp0 (key, infos->name) == 0) {
+		if (g_strcmp0 (key, infos->id) == 0) {
 			ArvInterfaceDeviceIds *ids;
 			GInetAddress *device_address;
 
-			ids = g_new0 (ArvInterfaceDeviceIds, 1);
-
-			ids->device = g_strdup (key);
-			ids->physical = g_strdup (infos->mac_string);
 			device_address = _device_infos_to_ginetaddress (infos);
+
+			ids = g_new0 (ArvInterfaceDeviceIds, 1);
+			ids->device = g_strdup (key);
+			ids->physical = g_strdup (infos->mac);
 			ids->address = g_inet_address_to_string (device_address);
-			g_object_unref (device_address);
-			ids->vendor = g_strdup (infos->manufacturer);
+			ids->vendor = g_strdup (infos->vendor);
 			ids->model = g_strdup (infos->model);
-			ids->serial_nbr = g_strdup (infos->serial_number);
+			ids->serial_nbr = g_strdup (infos->serial);
 
 			g_array_append_val (device_ids, ids);
+
+			g_object_unref (device_address);
 		}
 	}
 }
@@ -611,7 +621,7 @@ arv_gv_interface_open_device (ArvInterface *interface, const char *device_id)
 }
 
 static ArvInterface *gv_interface = NULL;
-ARV_DEFINE_STATIC_MUTEX (gv_interface_mutex);
+static GMutex gv_interface_mutex;
 
 /**
  * arv_gv_interface_get_instance:
@@ -624,12 +634,12 @@ ARV_DEFINE_STATIC_MUTEX (gv_interface_mutex);
 ArvInterface *
 arv_gv_interface_get_instance (void)
 {
-	arv_g_mutex_lock (&gv_interface_mutex);
+	g_mutex_lock (&gv_interface_mutex);
 
 	if (gv_interface == NULL)
 		gv_interface = g_object_new (ARV_TYPE_GV_INTERFACE, NULL);
 
-	arv_g_mutex_unlock (&gv_interface_mutex);
+	g_mutex_unlock (&gv_interface_mutex);
 
 	return ARV_INTERFACE (gv_interface);
 }
@@ -637,14 +647,14 @@ arv_gv_interface_get_instance (void)
 void
 arv_gv_interface_destroy_instance (void)
 {
-	arv_g_mutex_lock (&gv_interface_mutex);
+	g_mutex_lock (&gv_interface_mutex);
 
 	if (gv_interface != NULL) {
 		g_object_unref (gv_interface);
 		gv_interface = NULL;
 	}
 
-	arv_g_mutex_unlock (&gv_interface_mutex);
+	g_mutex_unlock (&gv_interface_mutex);
 }
 
 static void
